==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttp2RouteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property action Action to take if a match is determined.
 * @property match Criteria for determining a request match.
 */
public data class GatewayRouteSpecHttp2RouteArgs(
    public val action: Output<GatewayRouteSpecHttp2RouteActionArgs>,
    public val match: Output<GatewayRouteSpecHttp2RouteMatchArgs>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteArgs.builder()
            .action(action.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .match(match.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [GatewayRouteSpecHttp2RouteArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttp2RouteArgsBuilder internal constructor() {
    private var action: Output<GatewayRouteSpecHttp2RouteActionArgs>? = null

    private var match: Output<GatewayRouteSpecHttp2RouteMatchArgs>? = null

    /**
     * @param value Action to take if a match is determined.
     */
    @JvmName("dgovrrwieynyltqd")
    public suspend fun action(`value`: Output<GatewayRouteSpecHttp2RouteActionArgs>) {
        this.action = value
    }

    /**
     * @param value Criteria for determining a request match.
     */
    @JvmName("insgevnnmdcpfngu")
    public suspend fun match(`value`: Output<GatewayRouteSpecHttp2RouteMatchArgs>) {
        this.match = value
    }

    /**
     * @param value Action to take if a match is determined.
     */
    @JvmName("lnjinahgnjmoxwwn")
    public suspend fun action(`value`: GatewayRouteSpecHttp2RouteActionArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param argument Action to take if a match is determined.
     */
    @JvmName("xrgkuvhfinjapdxv")
    public suspend
    fun action(argument: suspend GatewayRouteSpecHttp2RouteActionArgsBuilder.() -> Unit) {
        val toBeMapped = GatewayRouteSpecHttp2RouteActionArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.action = mapped
    }

    /**
     * @param value Criteria for determining a request match.
     */
    @JvmName("jgnxhiqylnvgfkvt")
    public suspend fun match(`value`: GatewayRouteSpecHttp2RouteMatchArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.match = mapped
    }

    /**
     * @param argument Criteria for determining a request match.
     */
    @JvmName("qkelnyyhledccjwt")
    public suspend
    fun match(argument: suspend GatewayRouteSpecHttp2RouteMatchArgsBuilder.() -> Unit) {
        val toBeMapped = GatewayRouteSpecHttp2RouteMatchArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.match = mapped
    }

    internal fun build(): GatewayRouteSpecHttp2RouteArgs = GatewayRouteSpecHttp2RouteArgs(
        action = action ?: throw PulumiNullFieldException("action"),
        match = match ?: throw PulumiNullFieldException("match"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttp2RouteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property action Action to take if a match is determined.
 * @property match Criteria for determining a request match.
 */
public data class GatewayRouteSpecHttp2RouteArgs(
    public val action: Output<GatewayRouteSpecHttp2RouteActionArgs>,
    public val match: Output<GatewayRouteSpecHttp2RouteMatchArgs>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteArgs.builder()
            .action(action.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .match(match.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [GatewayRouteSpecHttp2RouteArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttp2RouteArgsBuilder internal constructor() {
    private var action: Output<GatewayRouteSpecHttp2RouteActionArgs>? = null

    private var match: Output<GatewayRouteSpecHttp2RouteMatchArgs>? = null

    /**
     * @param value Action to take if a match is determined.
     */
    @JvmName("mmfynnycvxfgjvdf")
    public suspend fun action(`value`: Output<GatewayRouteSpecHttp2RouteActionArgs>) {
        this.action = value
    }

    /**
     * @param value Criteria for determining a request match.
     */
    @JvmName("vcujssmduvdxenti")
    public suspend fun match(`value`: Output<GatewayRouteSpecHttp2RouteMatchArgs>) {
        this.match = value
    }

    /**
     * @param value Action to take if a match is determined.
     */
    @JvmName("unmbxhwdqhitbixb")
    public suspend fun action(`value`: GatewayRouteSpecHttp2RouteActionArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param argument Action to take if a match is determined.
     */
    @JvmName("abpsnjajreutvlsj")
    public suspend fun action(argument: suspend GatewayRouteSpecHttp2RouteActionArgsBuilder.() -> Unit) {
        val toBeMapped = GatewayRouteSpecHttp2RouteActionArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.action = mapped
    }

    /**
     * @param value Criteria for determining a request match.
     */
    @JvmName("uybnebkoewrlckyn")
    public suspend fun match(`value`: GatewayRouteSpecHttp2RouteMatchArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.match = mapped
    }

    /**
     * @param argument Criteria for determining a request match.
     */
    @JvmName("sdmhrkfyqewerasv")
    public suspend fun match(argument: suspend GatewayRouteSpecHttp2RouteMatchArgsBuilder.() -> Unit) {
        val toBeMapped = GatewayRouteSpecHttp2RouteMatchArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.match = mapped
    }

    internal fun build(): GatewayRouteSpecHttp2RouteArgs = GatewayRouteSpecHttp2RouteArgs(
        action = action ?: throw PulumiNullFieldException("action"),
        match = match ?: throw PulumiNullFieldException("match"),
    )
}
